@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-04-08'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2015-04-14'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -540,23 +540,6 @@ sub _process_script {
         $modified++;
     }
 
-    # insert FILES section
-    {
-        last unless $cli->read_config;
-        #$self->log_debug(["skipped file %s (script does not read config)", $filename]);
-        my @content;
-        my $config_filename = $cli->config_filename // $cli->program_name . ".conf";
-        my $config_dirs = $cli->{config_dirs} // ['~/.config', '~', '/etc'];
-
-        for my $config_dir (@{$config_dirs}) {
-            push @content, "$config_dir/$config_filename\n\n";
-        }
-
-        $self->add_text_to_section($document, join('', @content), 'FILES',
-                                   {after_section=>'ENVIRONMENT'});
-        $modified++;
-    }
-
     if ($modified) {
         $self->log(["added POD sections from Rinci metadata for script '%s'", $filename]);
     }
@@ -611,7 +594,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.39 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-08.
+This document describes version 0.40 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-14.
 
 =head1 SYNOPSIS
 
